let a,e,m;!function(a){a.language="language",a.system="system",a.comma_decimal="comma_decimal",a.decimal_comma="decimal_comma",a.space_comma="space_comma",a.none="none"}(a||(a={})),function(a){a.language="language",a.system="system",a.am_pm="12",a.twenty_four="24"}(e||(e={})),function(a){a.language="language",a.monday="monday",a.tuesday="tuesday",a.wednesday="wednesday",a.thursday="thursday",a.friday="friday",a.saturday="saturday",a.sunday="sunday"}(m||(m={}));export{m as F,a as N,e as T};
